# SQL Functions

This module contains wrappers for common SQL functions.

::: neopika.functions
    handler: python
    options:
      members: true
      show_root_heading: false
      show_source: true
      heading_level: 2 